﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.Collections.ObjectModel;
using Infragistics.Windows.DataPresenter;
using Infragistics.Windows.Editors;
using Infragistics.Windows;

namespace CustomFieldChooser
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        List<Field> fields_to_hide = new List<Field>();
        public MainWindow()
        {
            InitializeComponent();

            xamDataGrid1.DataSource = GenerateData();
        }

        private ObservableCollection<Parent> GenerateData()
        {
            ObservableCollection<Parent> data = new ObservableCollection<Parent>();

            for (int i = 0; i < 5; i++)
            {
                Parent p = new Parent()
                {
                    ID = i,
                    FirstName = "Parent " + i,
                    LastName = "Parent " + i,
                    Email = "Parent " + i + "@parentColleciton.com",
                    Children = new ObservableCollection<Child>()
                };

                for (int j = 0; j < 5; j++)
                {
                    p.Children.Add(new Child
                    {
                        ID = j,
                        ParentID = i,
                        Name = "Child " + j,
                        Age = i + j * 5
                    });
                }
                data.Add(p);
            }
            return data;
        }

        private void xamDataGrid1_FieldChooserOpening(object sender, Infragistics.Windows.DataPresenter.Events.FieldChooserOpeningEventArgs e)
        {
            FieldChooser fc = e.FieldChooser;

            fc.FieldFilters.Clear();
            Predicate<Field> predL1 = new Predicate<Field>(field => { return IsFieldVisibleL1(field); });

            FieldChooserFilter f = new FieldChooserFilter("My Filter", predL1, "filter");

            fc.FieldFilters.Add(f);
            fc.CurrentFieldGroup = fc.FieldGroups[1];
        }

        public bool IsFieldVisibleL1(Field f)
        {
            foreach (Field f1 in fields_to_hide)
                if (f1 == f)
                    return false;
            return true;
        }

        private void xamDataGrid1_FieldLayoutInitialized(object sender, Infragistics.Windows.DataPresenter.Events.FieldLayoutInitializedEventArgs e)
        {
            foreach (Field f in e.FieldLayout.Fields)
            {
                if (f.Name.Contains("ID"))
                {
                    fields_to_hide.Add(f);
                }
            }
        }
    }

    public class ComboItemVisibilityConverter : IValueConverter
    {
        public object Convert(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            FieldChooserGroup g = value as FieldChooserGroup;
            if (g != null)
            {
                if (g.FieldFilter == null)
                {
                    return false;
                }
            }

            return true;
        }

        public object ConvertBack(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            throw new NotImplementedException();
        }
    }


    public class Parent
    {
        public int ID { get; set; }
        public string FirstName { get; set; }
        public string LastName { get; set; }
        public string Email { get; set; }
        public ObservableCollection<Child> Children { get; set; }
    }

    public class Child
    {
        public int ID { get; set; }
        public string Name { get; set; }
        public int ParentID { get; set; }
        public int Age { get; set; }
    }

}
